function x = CPRL_CVX(b,A,epsilon,lambda)
%x = CPRL_CVX(b,A,epsilon,lambda)
%
% Computes the solution to
%
% min_X Tr(X) + lambda*||X||_1
%  s.t. ||sum_i b(i) - Tr(A(i,:)'*A(i,:)*X)||< epsilon,
%       X >= 0.        
%
% and returns the eigenvector with the largest 
% eigenvalue of X. Handles both complex and real A and 
% Xs. 
% Written by Henrik Ohlsson, ohlsson@isy.liu.se

[N n]=size(A);

%% CVX to solve the CPRL problem
cvx_begin SDP quiet
variable X(n,n) hermitian complex
variable e(N,1)  complex
variable traceVector(N,1) complex
minimize(trace(X) + lambda*sum(norms(X,1,1)))
subject to
for r=1:N
    traceVector(r,1) == trace(A(r,:)'*A(r,:)*X);
end
norms(traceVector-b) <= epsilon
X>=0
cvx_end

%% pick out the vector associated with the largest singular value
if any(isnan(X))
    x=NaN(size(X,1),1);
    display('NaN returned')
else
    [u s v]=svds(X,1);
    x=u*sqrt(s);
end

